class BGExceptions:
    def prepare_error_message(msg: str, status_code: int):
        return {
            "code": int(status_code),
            "message": msg,
        }


class TelegramExceptions:
    pass



import unittest

from src.pba_client.client import PBAClient


class TestCarNumberAPI(unittest.TestCase):
    def setUp(self) -> None:
        self.api_client = PBAClient("", "")

    def test_is_car_number_not_found(self):
        car_number = ""
        result_data = self.api_client.search_car_number(car_number)
        self.assertIn('code', result_data)
        self.assertIn('message', result_data)

        result_code = result_data.get("code")
        self.assertIsInstance(result_code, int)
        self.assertEqual(result_code, 404)

        result_message = result_data.get("message")
        self.assertIsInstance(result_message, str)
        self.assertEqual(result_message, "Invalid car number")


if __name__ == '__main__':
    unittest.main()



from http.client import NOT_FOUND
from .exceptions import BGExceptions as BGExc
from .exceptions import TelegramExceptions as TExc
from .apps.baza_gai import search_gai_base_car_number


class PBAClient:
    def __init__(self, host: str, api_key: str):
        self.host = host
        self.api_key = api_key

    def search_car_number(self, car_number: str):
        data = search_gai_base_car_number(car_number)

        if not data:
            return BGExc.prepare_error_message(
                msg="Invalid car number",
                status_code=NOT_FOUND,
            )
        return data










import posixpath

from urllib.parse import urljoin
import requests


def prepare_url(self, path=None):
    return urljoin(self.api_url,
                   posixpath.join("api/v1/telegram/users", path))


def create_telegram_user(self, user: dict):
    url = self.prepare_url()
    return requests.post(url, json=user).json()


def get_telegram_user(self, user: dict):
    url = self.prepare_url(f"{user.get('id')}")
    return requests.get(url).json()


def update_telegram_user(self, user: dict):
    url = self.prepare_url(f"{user.get('id')}")
    return requests.put(url, json=user).json()



import requests
from settings import *
from helper_baza_gai import *
from dto import CarEntity


def search_gai_base_car_number(car_number: str):
    url = f"https://baza-gai.com.ua/nomer/{car_number}"
    r = requests.get(url, headers={"Accept": "application/json", "X-Api-Key": GAI_KEY})
    car_data = r.json()
    car_data['photo_url'] = fix_baza_gai_image_url(car_data['photo_url'])
    formatted_data = CarEntity(
        digits=car_data['digits'],
        vin=car_data['vin'],
        vendor=car_data['vendor'],
        model_year=car_data['model_year'],
        photo_url=car_data['photo_url'],
        is_stolen=car_data['is_stolen'],
    )
    return formatted_data



import urllib.parse as url_parse


def fix_baza_gai_image_url(image_url: str):
    url_base = "https://baza-gai.com.ua"
    parsed_url = url_parse.urlsplit(image_url)
    url_path = url_parse.quote(parsed_url.path)
    return url_parse.urljoin(url_base, url_path)
